@@ -5,7 +5,7 @@ package Alt::Data::Frame::ButMore;
 use strict;
 use warnings;
 
-our $VERSION = '0.004_003'; # TRIAL VERSION
+our $VERSION = '0.004_004'; # TRIAL VERSION
 
 __END__
 
@@ -19,7 +19,7 @@ Alt::Data::Frame::ButMore - Alternative implementation of Data::Frame with more
 
 =head1 VERSION
 
-version 0.004_003
+version 0.004_004
 
 =head1 STATUS
 
@@ -29,7 +29,7 @@ This library is current experimental.
 
     use Alt::Data::Frame::ButMore;
     use Data::Frame;
-    use PDL::Core qw(pdl);
+    use PDL;
 
     my $df = Data::Frame->new(
             columns => [
@@ -51,7 +51,7 @@ This library is current experimental.
     say $df->at(0);
     # [1 2 3 4]
 
-    say $df->select_rows( 3,1 )
+    say $df->select_rows( 3,1 );
     # ---------------
     #     z  y  x
     # ---------------
@@ -73,14 +73,11 @@ This library is current experimental.
 =head1 DESCRIPTION
 
 It's been too long I cannot reach ZMUGHAL.
-So here I release my [Alt](https://metacpan.org/pod/Alt) implenmentation.
+So here I release my L<Alt> implenmentation.
 
 This implements a data frame container that uses L<PDL> for individual columns.
 As such, it supports marking missing values (C<BAD> values).
 
-The API is currently experimental and is made to work with
-L<Statistics::NiceR>, so be aware that it could change.
-
 =head1 CONSTRUCTION
 
     new( (ArrayRef | HashRef) :$columns,
