@@ -87,6 +87,7 @@ use overload (
 
 # Relative tolerance. This can be used for data frame comparison.
 our $TOLERANCE_REL = undef;
+our $doubleformat = '%.8g';
 
 # Check if all columns have same length or have a length of 1.
 around BUILDARGS($orig, $class : @args) {
@@ -164,17 +165,37 @@ sub BUILD {
 
 
 method _string() {
+    my $format_cell = sub {
+        my ( $col, $ridx ) = @_;
+
+        if ( $col->$_DOES('PDL::DateTime') ) {
+            return $col->dt_at($ridx);
+        }
+        elsif ( $self->_is_numeric_column($col) ) {
+            if ( $col->type >= PDL::float ) {
+
+                # This is to fix some float precision problem with perl
+                # of nvsize=16, which can cause $df->string to get untidy
+                # float data to cause our test to fail.
+                my $s = $col->slice($ridx)->squeeze->string;
+                if ( $s eq 'BAD' ) {
+                    return $s;
+                }
+                else {
+                    return sprintf( $doubleformat, $s );
+                }
+            }
+        }
+        return $col->slice($ridx)->squeeze->string;
+    };
+
     my @rows = ( [ '', @{ $self->column_names } ] );
     for my $r_idx ( 0 .. $self->number_of_rows - 1 ) {
         my $r = [
             $self->row_names->slice($r_idx)->squeeze->string,
             map {
                 my $col = $self->nth_column($_);
-                if ($col->$_DOES('PDL::DateTime')) {
-                    $col->dt_at($r_idx);
-                } else {
-                    $col->slice($r_idx)->squeeze->string
-                }
+                $format_cell->( $col, $r_idx );
             } 0 .. $self->number_of_columns - 1
         ];
         push @rows, $r;
@@ -709,7 +730,12 @@ method assign ((DataFrame | Piddle) $x) {
 
 method is_numeric_column ($column_name_or_idx) {
     my $column = $self->at($column_name_or_idx);
-    return !is_discrete($column);
+    return $self->_is_numeric_column($column);
+}
+
+sub _is_numeric_column {
+    my ($self, $piddle) = @_;
+    return !is_discrete($piddle);
 }
 
 
@@ -980,7 +1006,7 @@ Data::Frame - data frame implementation
 
 =head1 VERSION
 
-version 0.004_003
+version 0.004_004
 
 =head1 STATUS
 
@@ -990,7 +1016,7 @@ This library is current experimental.
 
     use Alt::Data::Frame::ButMore;
     use Data::Frame;
-    use PDL::Core qw(pdl);
+    use PDL;
 
     my $df = Data::Frame->new(
             columns => [
@@ -1012,7 +1038,7 @@ This library is current experimental.
     say $df->at(0);
     # [1 2 3 4]
 
-    say $df->select_rows( 3,1 )
+    say $df->select_rows( 3,1 );
     # ---------------
     #     z  y  x
     # ---------------
@@ -1034,14 +1060,11 @@ This library is current experimental.
 =head1 DESCRIPTION
 
 It's been too long I cannot reach ZMUGHAL.
-So here I release my [Alt](https://metacpan.org/pod/Alt) implenmentation. 
+So here I release my L<Alt> implenmentation.  
 
 This implements a data frame container that uses L<PDL> for individual columns.
 As such, it supports marking missing values (C<BAD> values).
 
-The API is currently experimental and is made to work with
-L<Statistics::NiceR>, so be aware that it could change.
-
 =head1 CONSTRUCTION
 
     new( (ArrayRef | HashRef) :$columns,
